@@ -1877,7 +1877,7 @@ and type_try ctx e1 catches with_type p =
 	in
 	let check_catch_type_params params =
 		List.iter (fun pt ->
-			if pt != t_dynamic then error "Catch class parameter must be Dynamic" p;
+			if Abstract.follow_with_abstracts pt != t_dynamic then error "Catch class parameter must be Dynamic" p;
 		) params
 	in
 	let catches,el = List.fold_left (fun (acc1,acc2) ((v,pv),t,e_ast,pc) ->
@@ -2219,7 +2219,8 @@ and type_return ?(implicit=false) ctx e with_type p =
 		end;
 		try
 			let with_expected_type =
-				if implicit then WithType.of_implicit_return ctx.ret
+				if ExtType.is_void (follow ctx.ret) then WithType.no_value
+				else if implicit then WithType.of_implicit_return ctx.ret
 				else WithType.with_type ctx.ret
 			in
 			let e = type_expr ctx e with_expected_type in
